@@ -23,6 +23,16 @@ class TargetField
 public:
 	TargetField() {
 		id = -1;
+		originalName = "";
+	}
+	TargetField(TargetField * copy) {
+		this->id = copy->id;
+		this->name = copy->name;
+		this->type = copy->type;
+		this->encrypted = copy->encrypted;
+		this->order = copy->order;
+		this->originalName = copy->originalName;
+		this->value = copy->value;
 	}
 	~TargetField();
 
@@ -32,14 +42,26 @@ public:
 		this->type = type;
 		this->encrypted = encrypted;
 		this->order = order;
+		this->originalName = name;
 	}
 
+	TargetField(QString name, int type, bool encrypted, int order, QString original) {
+		this->id = -1;
+		this->name = name;
+		this->type = type;
+		this->encrypted = encrypted;
+		this->order = order;
+		this->originalName = original;
+	}
+
+
 	int id;
 	int targetId;
 
 	int order;
 	bool encrypted;
 	QString name;
+	QString originalName;
 	QString value;
 	int type;
 };
@@ -69,6 +91,8 @@ public:
 	QString getSummary ();
 
 	bool existField (QString name);
+	int getFieldByName (QString name);
+
 //private:
 	QImage * pictureSmall;
 	QImage * picture;
