@@ -285,7 +285,7 @@
         <location filename="../../DetailedWindow.cpp" line="775"/>
         <location filename="../../DetailedWindow.cpp" line="913"/>
         <source>Images (*.png);;</source>
-        <translation>Imagenes (*.png);</translation>
+        <translation>Imagenes PNG (*.png)</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="787"/>
@@ -296,7 +296,7 @@
         <location filename="../../DetailedWindow.cpp" line="789"/>
         <location filename="../../DetailedWindow.cpp" line="928"/>
         <source>Images (*.png *.jpg *.gif *.jpeg);;</source>
-        <translation>Imagenes (*.png *.jpg *.gif *.jpeg);</translation>
+        <translation>Imagenes (*.png *.jpg *.gif *.jpeg)</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="911"/>
@@ -808,7 +808,7 @@
         <location filename="../../eWallet.cpp" line="1132"/>
         <location filename="../../eWallet.cpp" line="1407"/>
         <source>Text files (*.txt);;</source>
-        <translation>Archivos de texto (*.txt);</translation>
+        <translation>Archivos de texto (*.txt)</translation>
     </message>
     <message>
         <location filename="../../eWallet.cpp" line="1380"/>
